import React, {Component, useState} from 'react';
import {
  View,
  Text,
  Dimensions,
  StyleSheet,
  TouchableOpacity,
  KeyboardAvoidingView,
  TouchableWithoutFeedback,
  ScrollView,
  Keyboard,
  Platform,
} from 'react-native';
import HeaderBack from '../../components/Header/HeaderBack';
import PickerItem from '../../components/Picker/PickerItem';
import I18n from '../../helper/i18/i18n';
import AppText from '../../components/AppText';
import TextField from '../../components/Input/TextField';
import {getFontXD, HEIGHTXD, WIDTHXD} from '../../Config/Functions';
import R from '../../assets/R';
import RadioForm, {
  RadioButton,
  RadioButtonInput,
  RadioButtonLabel,
} from 'react-native-simple-radio-button';

var radio_props = [
  {label: 'Mua', value: 0},
  {label: 'Bán', value: 1},
];

const dataType = [
  {
    value: '0',
    name: 'Ngô mini',
  },
  {
    value: '1',
    name: 'Đỗ mini',
  },
];

const {width} = Dimensions.get('window');

const CaculatedStopLoss = (props) => {
  const [product, setProduct] = useState();
  const [type, setType] = useState('BUY');
  const [lot, setLot] = useState('BUY');
  const [priceOpen, setPriceOpen] = useState(525);
  const [fee, setFee] = useState(0);
  const [surplus, setSurplus] = useState(0);

  const [inSession, setInSession] = useState(0);
  const [priceClose, setPriceClose] = useState(525);

  return (
    <View style={{flex: 1}}>
      <HeaderBack title={'CaculatedStopLoss'} />
      <KeyboardAvoidingView
        behavior={Platform.Os === 'ios' ? 'padding' : 'height'}
        style={{flex: 1}}
        keyboardVerticalOffset={-50}>
        <TouchableWithoutFeedback onPress={Keyboard.dismiss}>
          <ScrollView showsVerticalScrollIndicator={false}>
            <View style={{flex: 1, paddingHorizontal: 10, paddingTop: 5}}>
              <AppText style={styles.txtTitle} i18nKey={'Product'} />
              <PickerItem
                width={width - 20}
                data={dataType}
                onValueChange={(value, items) => {
                  setProduct(items);
                }}
              />

              <AppText style={styles.txtTitle} i18nKey={'Tradding'} />
              <RadioForm
                formHorizontal={true}
                labelHorizontal={true}
                radio_props={radio_props}
                style={styles.row}
                initial={0}
                onPress={(value) => {
                  console.log({value: value});
                }}
              />
              <TextField title={I18n.t('CountLotTradding')} />
              <TextField title={I18n.t('PriceOpen')} />
              <TextField title={I18n.t('FeeTradding')} />
              <TextField title={I18n.t('SurpusInit')} />
              <TextField title={I18n.t('withdrawalsSession')} />
              <TextField title={I18n.t('PriceClose')} />
              <TextField title={I18n.t('PriceStopLoss')} />
              <AppText style={styles.note} i18nKey={'noteStopLoss'} />
              <View style={styles.footer}>
                <TouchableOpacity style={styles.btnContainer}>
                  <AppText style={styles.txtBtn} i18nKey={'Caculate'} />
                </TouchableOpacity>
              </View>
            </View>
          </ScrollView>
        </TouchableWithoutFeedback>
      </KeyboardAvoidingView>
    </View>
  );
};

const styles = StyleSheet.create({
  txtTitle: {
    fontSize: getFontXD(42),
    color: R.colors.color777,
    marginTop: 15,
  },
  note: {
    fontSize: getFontXD(36),
    fontStyle: 'italic',
    marginTop: 10,
  },
  row: {
    height: HEIGHTXD(109),
    width: '80%',
    justifyContent: 'space-between',
    marginVertical: 5,
    paddingHorizontal: 10,
  },
  footer: {
    alignItems: 'center',
    justifyContent: 'center',
    marginTop: 20,
  },
  btnContainer: {
    width: WIDTHXD(428),
    height: HEIGHTXD(120),
    justifyContent: 'center',
    alignItems: 'center',
    backgroundColor: R.colors.main,
    borderRadius: 10,
  },
  txtBtn: {
    fontSize: getFontXD(48),
    color: R.colors.white,
    fontWeight: '600',
  },
});

export default CaculatedStopLoss;
